
$Su_version=Sketchup.version.split(".").first.to_i
$load_vray=0

module VRayForSketchUp

def self.isThisDarwin
  retval = false
  osType = RUBY_PLATFORM
  result = osType["darwin"]
  if result != nil
      retval = true
  end
  return retval
end

def self.isThisWindows
  return nil != (RUBY_PLATFORM =~ /mswin|mingw|cygwin/)
end

# This function should only be called on Windows - this path won't exist on Mac
def self.getWindowsASGVISFolder()
    require 'RubyWinFunc.so'
    path = WinFunc.commonAppDataPath()
    return "#{path}/ASGVIS"
end

def self.findPluginsFolder()
    for folder in $LOAD_PATH
        filename = File.join( folder, "vfs.rb")
        return folder if File.exists?( filename )        
    end    
end

def self.getMacASGVISFolder()
    return "#{self.findPluginsFolder()}"
end

def self.getASGVISRubyFolder()
    if self.isThisDarwin
        return self.getMacASGVISFolder()
    else
        return self.getWindowsASGVISFolder()
    end
end

def self.setupPath()
	asgvis_folder = "#{self.getASGVISRubyFolder()}"
	vfs_folder = "#{asgvis_folder}/VfS"
	asgvis_ruby_folder = "#{vfs_folder}/Ruby"
	asgvis_toolbar_images_folder = "#{asgvis_ruby_folder}/images"
	$LOAD_PATH << asgvis_folder
	$LOAD_PATH << vfs_folder
	$LOAD_PATH << asgvis_ruby_folder
	$LOAD_PATH << asgvis_toolbar_images_folder
end

def self.getVRayForSketchUpVersion()
    return PythonBridge.get_build_version()
end

def self.registerExtension()
	vray_extension = SketchupExtension.new "V-Ray For SketchUp", "R2P.rb"
	vray_extension.version = self.getVRayForSketchUpVersion()
	vray_extension.description = "Allows you to render your SketchUp scene with V-Ray"
	vray_extension.copyright = "(c) 2012 Chaos Software, Ltd"
	vray_extension.creator = "Chaos Software, Ltd"
	Sketchup.register_extension vray_extension, true
end

end # module VRayForSketchUp

# Back up path, we potentially change it 


def load_vray2
if( not file_loaded?("vfs.rb") ) and $load_vray==1
require 'sketchup.rb'
require 'extensions.rb'


path = ENV["PATH"]
begin
  VRayForSketchUp.setupPath
  # Alter the path so that we can find our DLLs on windows. This lets us not install to program files
  ENV["PATH"] = "#{VRayForSketchUp.getASGVISRubyFolder()}/VfS;#{path}" if VRayForSketchUp.isThisWindows()

  if VRayForSketchUp.isThisDarwin
    require 'RubyToPython.bundle'
  else
    require "RubyToPython.so"
  end

  VRayForSketchUp.registerExtension()
ensure
  # Restore path after we're loaded
  ENV["PATH"]=path
end
end# if( not file_loaded?("vfs.rb") )
end

artmine_list_encoded="iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAHXElEQVR42rWWaVRTdxrG3/+9uckN"+
"WQgYCBASIBJBkAgiqNCKolXRgLgBU6ke3NcRpYN1RB23StW2ti6Iu1axWvddcd8QWwWrHRAiKCCL"+
"LAkk4YYk9/6r09MPc6ZnnH6Y5+O7nN+n93leBP9noT8qpuyshKPTtZC47hoSyz2RuaUJHNZ2IPk0"+
"cKQQX1oaj0efxcDWGeDcbO3/DlAmfArxI0cDdgtE59O9ceSqq8A0VcGDs9vA3ScQ1L0HgzQgGl4+"+
"vg6hGdnoxQ/XcU+dFE5kRr0f4LvkF8Cle2F0ajrUNFvg0ZndEBSX9KGQFo6kCCQjEMk5AVW3sS6X"+
"udbnT+UjJkPJpmNIN0iJLy6O+e8A3wU3QMSnwPLsNOGp8ueUPfrQBHDfCgk2re21odJosVoIRFAi"+
"kUgmce0moSXyc07fnqulEq6+8Uk5UXY4mwsatQiurB37n4DuY3KA0SSCBBjCUnqEM5MyoSpSv7WH"+
"Jz+ps6nipcpbTgCGTqbT4uxiGMJus7ph98Be/v7da3gKMplt6Cy5sGUhaIZORzRFwZnlejxk3UO4"+
"tiT6N4DELxjcJx6BV2IduJcdUPop3A7NURUPCG7OG6J//nXU9LG9siihVEgiRIuEfJKxdDi/P3j4"+
"O37AYI1Wq/UbFSL4+M6L9sb6ip/rqbcAZdpoVHWqGDs5Fm7lxAJSRCfxiODxTpMi1sfHXrEzwnaL"+
"KVDnqqko1xSwiF9KM4Xdg2OG+TsUUd28wOIyLFzWqFWri2sKpi5vCJyZ+U/3cTXtZVd/prxD61iW"+
"W0/zBdU2zCMYi4m7uzIeUP9Vj4XyID+m6cK2ve0fZFYffCq54ePvWeAwEvHqnmQluVgPUKsHw/bV"+
"YKeE0FhPBfhphCc1ttKyizhif45hzi4BRS51NJWrqG7BqRK55wSb2VwOiIVnjA8g/7HLAVFUuKuX"+
"dh8aoIhZVZI6uI8nedhuAb2/ind77Na5vBMFl/GxfQwrkEjjdQHoNN9p3u879N48vdUML5ZtzZeF"+
"DoS6opMzPYPoXKCidI82b0rSZWQ4n4mHA4qYfxBsxoa/ShXq/rzdcz/u3ZfunfmR7Ia3jFpKCeg8"+
"ws2NolScY3vugz6JEz662fqy7FBzVevstORCkrfxIHaXi0aLvbtnKkrzEs5eP0xEL7p9X6AMmtfV"+
"1nwbYY5Eaec7ofzUjg0u7t5MS1Pz8lkhiyUxgoF3QrUeleaXhtQWfgC22WoVIomyiGdpqnDX70qg"+
"HK/hL+O+QLUh4azDCVEy38AvxmdMnrrnb4ZqSdCdE7TYtZBykeaxDoaPMi53Qtmp/A0uclXXq5r6"+
"nJ3xeWBpjNwY3UM+mXZVRotCXatvHX16MrSnR5yVDAoTikWvmTdPUcpFCfAsRmxncT+Rp3qN1Dcm"+
"o7yhqE7p5I4JxNJCwgH5HJ+g0KDsnWCsr5njrQ0bXFR0Ji0NN7DFD27GHv9+3U2Wc8zfuqWwdsWy"+
"tHM/3X2YHj55/SGn5Q35qPgSu6SQIVvbTFyg0mOC2EM1sZ/o9bh/3JXyEyIkhXyhZCnLsTffXjEP"+
"+UQNgQHhOh3qHlvQb+S4pPtFT6pOTFJTdwq+uqBSq0IdGLGkvbPEI/aTZNxVgV29BuB3B1ReXsUz"+
"Y+RcsufSPl8/7auyiucrtFJHil2iXijpphgqE/GtYmUPQH2Tp1E7P892rNh/5XSPyIHmO5XN6afC"+
"iyF1Sk7qkR+2HZZJxczJo1c+1PgHPA4K00C/RQWwcs0a3g0Hdtp/Kk2w0Yp1VkKcaLDJGvpQr+4B"+
"X7wbAd4BnBP5BOkwiv0ki753+apNFxkWGZ8643ZUeEjuxHD5aovJyC/cvfJ2sMbnSUmpYVbYiP6E"+
"khKxqXtewKTkYXCCEMRZ7/6Sz6fphVMGBV88WlicL3L3UlS3MBMIzLJims+d+iwRUGz6IhiUmAZm"+
"xgY/Xjo2d2T6rC0Kj26743x5G3NmTRJohKhZzHfUT5mXDO28YN6Ki7WKDrNttpwWDJ8yJOSzBnno"+
"tQ7D42+evLH3lStV+h8flhgFFA8RJIVP/w4IjhgAdy8cQTOWbcKFx7/LCoyIWd/VaTFTFO+AHVAl"+
"S7uyRGeHhAa7bxeHPI2dXeVWZ9e3m3Wk5ptG+bqWDmuHyWqdKvNSG1vr6lBbuxX7e8vheLb+N7te"+
"uPcm7FgxG6w1ZZCU9TU0v6kbHhTSe6mL0KVXp42pdXQxBo7jap0YV3F2uyEyMkrSZrUnVJvsWi+h"+
"80Dtk/v5mogP3loug6qNHLbbHXBrbdq/B45MGwGmyhLQL9yI2loa8fnNOcKUrNw4uSowTiSRylnW"+
"SZA8HqJdRLTd4WTa21pvIL7wnMnYZrq0fi5A2Ew0Y9oIvGPBmD9OtN8B7zQq6yvi/JeLuO3FRpjV"+
"zw3EUncQe3jJCIKHgvsP7RiWnMJaWBIYswmMFgu5Z8EYVpayFsYP7A275unfH/rvhDFGKX/fjKZ9"+
"Ph+2Z3/Jndzw6b/qubcawVRXSbxtQ4fZgvNmj8B/+qt4zyz+EzvwK8xaNi9BI4sqAAAAAElFTkSu"+
"QmCC"


path=Sketchup.find_support_file("Plugins")
file=File.open(path+'/artmine_list.png', 'wb')
file.write(artmine_list_encoded.unpack("m")[0])
file.close
toolbar = UI::Toolbar.new "载入 Vray 2.0"
cmd = UI::Command.new("载入 Vray 2.0") { 
$load_vray=1

load_vray2
}
cmd.small_icon = cmd.small_icon ="artmine_list.png"
cmd.large_icon = cmd.large_icon ="artmine_list.png"
cmd.status_bar_text = "载入 Vray 2.0"
cmd.tooltip = "载入 Vray 2.0"
toolbar.add_item(cmd)
 toolbar.show		
File.delete path+"/artmine_list.png" 
 